==================================
UBCS LCP auxiliary package library
==================================

.. image:: https://img.shields.io/travis/vstadnytskyi/auxiliary.svg
        :target: https://travis-ci.org/vstadnytskyi/auxiliary

.. image:: https://img.shields.io/pypi/v/ubcs-auxiliary.svg
        :target: https://pypi.python.org/pypi/ubcs-auxiliary


UBCS LCP auxiliary package library

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://vstadnytskyi.github.io/auxiliary.

Features
--------

* TODO
